[−][src]Crate python_launcher
Structs
| Version | The version of Python found. |
Enums
| Action | |
| RequestedVersion | Represents the version of Python a user requsted. |
| VersionMatch | Represents how tight of a match a |
Functions
| action_from_args | Figure out what action is being requested based on the arguments to the executable. |
| available_executables | Find all available executables that are acceptable for the requested version as found on |
| choose_executable | Finds the executable representing the latest Python version. |
| directory_contents | Gets the contents of a directory. |
| filter_python_executables | Filters the paths down to |
| find_shebang | Finds the shebang line from |
| path_entries | Convert |
| split_shebang | Split the shebang into the Python version specified and the arguments to pass to the executable. |
| version_from_flag | Attempts to find a version specifier from a CLI argument. |
| virtual_env | Returns the path to the activated virtual environment. |