Struct python_launcher::Version [−][src]
pub struct Version { /* fields omitted */ }The version of Python found.
Methods
impl Version[src]
impl Versionpub fn matches(&self, requested: &RequestedVersion) -> VersionMatch[src]
pub fn matches(&self, requested: &RequestedVersion) -> VersionMatchTrait Implementations
impl Debug for Version[src]
impl Debug for Versionfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for Version[src]
impl PartialEq for Versionfn eq(&self, other: &Version) -> bool[src]
fn eq(&self, other: &Version) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Version) -> bool[src]
fn ne(&self, other: &Version) -> boolThis method tests for !=.
impl Eq for Version[src]
impl Eq for Versionimpl Hash for Version[src]
impl Hash for Versionfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl PartialOrd for Version[src]
impl PartialOrd for Versionfn partial_cmp(&self, other: &Version) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &Version) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &Version) -> bool[src]
fn lt(&self, other: &Version) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &Version) -> bool[src]
fn le(&self, other: &Version) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &Version) -> bool[src]
fn gt(&self, other: &Version) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &Version) -> bool[src]
fn ge(&self, other: &Version) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for Version[src]
impl Ord for Versionfn cmp(&self, other: &Version) -> Ordering[src]
fn cmp(&self, other: &Version) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more